@@ -36,7 +36,7 @@ static const WeekDays WEEKDAYS[] =
 static const WeekDays *mru_weekdays = NULL;
 
 static int
-weekday_search(const WeekDays *weekdays, const char *str, int len)
+weekday_search(const WeekDays *weekdays, const char *str, size_t len)
 {
 	int		i;
 
@@ -114,7 +114,7 @@ PG_FUNCTION_INFO_V1(orafce_dbtimezone);
  */
 
 int
-ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max)
+ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], size_t max)
 {
 	int		i;
 
@@ -195,7 +195,7 @@ next_day(PG_FUNCTION_ARGS)
 		int		i;
 		int		encoding = GetDatabaseEncoding();
 
-		for (i = 0; i < lengthof(WEEKDAYS); i++)
+		for (i = 0; i < (int) lengthof(WEEKDAYS); i++)
 		{
 			if (encoding == WEEKDAYS[i].encoding)
 			{
@@ -292,7 +292,7 @@ days_of_month(int y, int m)
  *
  * Syntax:
  *
- * float8 months_between(date date1, date date2)
+ * numeric months_between(date date1, date date2)
  *
  * Purpose:
  *
@@ -680,6 +680,8 @@ get_session_timezone(FunctionCallInfo fcinfo)
 #endif
 }
 
+#define TRUNC_DAY	tm->tm_hour = 0; tm->tm_min = 0; *redotz = true;
+
 /*
  * redotz is used only for timestamp with time zone
  */
@@ -704,21 +706,33 @@ tm_trunc(struct pg_tm *tm, text *fmt, bool *redotz)
 		j2date(_ora_date_trunc(DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday), f)
 			   + POSTGRES_EPOCH_JDATE,
 		&tm->tm_year, &tm->tm_mon, &tm->tm_mday);
-		tm->tm_hour = 0;
-		tm->tm_min = 0;
-		*redotz = true;
+		TRUNC_DAY;
 		break;
+
 	CASE_fmt_YYYY
 		tm->tm_mon = 1;
+		tm->tm_mday = 1;
+		TRUNC_DAY;
+		break;
+
 	CASE_fmt_Q
 		tm->tm_mon = (3*((tm->tm_mon - 1)/3)) + 1;
+		tm->tm_mday = 1;
+		TRUNC_DAY;
+		break;
+
 	CASE_fmt_MON
 		tm->tm_mday = 1;
+		TRUNC_DAY;
+		break;
+
 	CASE_fmt_DDD
-		tm->tm_hour = 0;
-		*redotz = true; /* for all cases >= DAY */
+		TRUNC_DAY;
+		break;
+
 	CASE_fmt_HH
 		tm->tm_min = 0;
+		break;
 	}
 }
 
