@@ -989,3 +989,33 @@ select plunit.assert_not_equals(1,2,3);
 -- lexer text
 --
 SELECT pos, token, class, mod FROM plvlex.tokens('select * from a.b.c join d on x=y', true, true);
+
+--
+-- trigger functions
+--
+
+CREATE TABLE trg_test(a varchar, b int, c varchar, d date, e int);
+
+CREATE TRIGGER trg_test_xx BEFORE INSERT OR UPDATE
+  ON trg_test FOR EACH ROW EXECUTE PROCEDURE oracle.replace_empty_strings(true);
+
+\pset null ***
+
+INSERT INTO trg_test VALUES('',10, 'AHOJ', NULL, NULL);
+INSERT INTO trg_test VALUES('AHOJ', NULL, '', '2020-01-01', 100);
+
+SELECT * FROM trg_test;
+
+DELETE FROM trg_test;
+
+DROP TRIGGER trg_test_xx ON trg_test;
+
+CREATE TRIGGER trg_test_xx BEFORE INSERT OR UPDATE
+  ON trg_test FOR EACH ROW EXECUTE PROCEDURE oracle.replace_null_strings();
+
+INSERT INTO trg_test VALUES(NULL, 10, 'AHOJ', NULL, NULL);
+INSERT INTO trg_test VALUES('AHOJ', NULL, NULL, '2020-01-01', 100);
+
+SELECT * FROM trg_test;
+
+DROP TABLE trg_test;
